==> order-center-api-2.9.0-CLOUD-20220819.123154-6-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInspOrderInfoBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInspOrderInfoBo
 * 说明:验收单信息
 * 时间:2022-02-21 19:11
 * 作者:tkl
 **/
@Data
public class UocGetSaleOrderDetailServiceRspInspOrderInfoBo implements Serializable {
    private static final long serialVersionUID = -6687385746152916212L;

    @DocField(value = "验收单id")
    private Long inspOrderId;

    @DocField(value = "执行明细id")
    private Long implOrderItemId;

    @DocField(value = "销售单id")
    private Long saleOrderId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "发货单编码")
    private String inspOrderNo;

    @DocField(value = "外部发货单编码")
    private String inspOrderNoExt;

    @DocField(value = "验收单名称")
    private String inspOrderName;

    @DocField(value = "验收单类型")
    private Integer inspOrderType;

    @DocField(value = "验收单状态")
    private String inspOrderState;

    @DocField(value = "验收单状态翻译")
    private String inspOrderStateStr;

    @DocField(value = "销售金额")
    private BigDecimal totalSaleFee;

    @DocField(value = "采购金额")
    private BigDecimal totalPurchaseFee;

    @DocField(value = "实付金额")
    private BigDecimal usedFee;

    @DocField(value = "开票标识 0未开票 1已开票")
    private Integer invoiceTag;

    @DocField(value = "流转状态")
    private String procState;

    @DocField(value = "对账状态")
    private String checkState;

    @DocField(value = "租户ID")
    private String tenantId;

    @DocField(value = "竣工标志             1 竣工             0 在途")
    private Integer finishFlag;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "验收人电话")
    private String inspOperPhone;

    @DocField(value = "验收人名字")
    private String inspOper;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "撤单时间")
    private Date cancelTime;

    @DocField(value = "撤单工号")
    private String cancelOperId;

    @DocField(value = "撤单原因")
    private String cancelReason;

    @DocField(value = "撤单标志:1 已撤单             0 未撤单")
    private Integer cancelFlag;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "其它备注")
    private String otherRemark;

    @DocField(value = "竣工时间")
    private Date finishTime;

    @DocField(value = "逾期时间")
    private Date expTime;

    @DocField(value = "总金额")
    private BigDecimal totalFee;

    @DocField(value = "总数量")
    private Integer totalCount;

    @DocField(value = "验收明细")
    private List<UocGetSaleOrderDetailServiceRspInspOrderItemInfoBo> inspOrderItemInfo;

    @DocField(value = "验收发货关系")
    private List<UocGetSaleOrderDetailServiceRspShipInspRelBo> shipInspRel;

    @DocField(value = "纵向扩展")
    private List<UocGetSaleOrderDetailServiceRspInspOrderExtParallelBo> extParallelBoList;

}

==> order-center-api-3.0.0-CLOUD-20250904.024321-86-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInspOrderInfoBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInspOrderInfoBo
 * 说明:验收单信息
 * 时间:2022-02-21 19:11
 * 作者:tkl
 **/
@Data
public class UocGetSaleOrderDetailServiceRspInspOrderInfoBo implements Serializable {
    private static final long serialVersionUID = -6687385746152916212L;

    /**验收单id*/
    private Long inspOrderId;

    /**执行明细id*/
    private Long implOrderItemId;

    /**销售单id*/
    private Long saleOrderId;

    /**订单id*/
    private Long orderId;

    /**发货单编码*/
    private String inspOrderNo;

    /**外部发货单编码*/
    private String inspOrderNoExt;

    /**验收单名称*/
    private String inspOrderName;

    /**验收单类型*/
    private Integer inspOrderType;

    /**验收单状态*/
    private String inspOrderState;

    /**验收单状态翻译*/
    private String inspOrderStateStr;

    /**销售金额*/
    private BigDecimal totalSaleFee;

    /**采购金额*/
    private BigDecimal totalPurchaseFee;

    /**实付金额*/
    private BigDecimal usedFee;

    /**开票标识 0未开票 1已开票*/
    private Integer invoiceTag;

    /**流转状态*/
    private String procState;

    /**对账状态*/
    private String checkState;

    /**租户ID*/
    private String tenantId;

    /**竣工标志             1 竣工             0 在途*/
    private Integer finishFlag;

    /**创建时间*/
    private Date createTime;

    /**创建工号*/
    private String createOperId;

    /**验收人电话*/
    private String inspOperPhone;

    /**验收人名字*/
    private String inspOper;

    /**更新时间*/
    private Date updateTime;

    /**更新工号*/
    private String updateOperId;

    /**撤单时间*/
    private Date cancelTime;

    /**撤单工号*/
    private String cancelOperId;

    /**撤单原因*/
    private String cancelReason;

    /**撤单标志:1 已撤单             0 未撤单*/
    private Integer cancelFlag;

    /**备注*/
    private String remark;

    /**其它备注*/
    private String otherRemark;

    /**竣工时间*/
    private Date finishTime;

    /**逾期时间*/
    private Date expTime;

    /**总金额*/
    private BigDecimal totalFee;

    /**总数量*/
    private Integer totalCount;

    /**验收明细*/
    private List<UocGetSaleOrderDetailServiceRspInspOrderItemInfoBo> inspOrderItemInfo;

    /**验收发货关系*/
    private List<UocGetSaleOrderDetailServiceRspShipInspRelBo> shipInspRel;

    /**纵向扩展*/
    private List<UocGetSaleOrderDetailServiceRspInspOrderExtParallelBo> extParallelBoList;

    /**
     * 租户id
     */
    private Long sysTenantId;
    private String sysTenantName;

}
